@@ -71,16 +71,6 @@ class GroupSvg(models.Model):
     def __str__(self):
         return self.key.title()
 
-    @cached_property
-    def key_composer(self):
-        """
-        Unique key Identifier of ``GroupSvg``
-        """
-        return "%s-%s" % (
-            self.collection.key,
-            self.key
-        )
-
     @cached_property
     def path_entry(self):
         """
